Crate entropy

Crate entropy 

entropy — pure, safe Rust statistical test suite for pseudorandom number generators.

Test suites

ModuleSource
nistNIST SP 800-22 Rev 1a [nist-sp-800-22]
diehardDIEHARD (Marsaglia, 1995) [marsaglia1995diehard]
dieharderDIEHARDER (Brown, 2006) [brown2006dieharder]

Modules

diehard
DIEHARD battery tests not already covered by NIST SP 800-22.
dieharder
DIEHARDER tests not covered by NIST SP 800-22 or DIEHARD.
math
Special mathematical functions used across all test suites.
nist
NIST SP 800-22 Rev 1a — all 15 statistical tests.
research
Research-grade tests and analyses drawn from the bibliography in BIB.md.
result
Test result type used by every test in the suite.
rng
Rng trait and all generator implementations used by the test suite.
seed
Deterministic seeding helpers shared across all auxiliary probe binaries.