pub struct BsdRandom { /* private fields */ }Expand description
BSD random() with the default 128-byte TYPE_3 state (deg=31, sep=3).
This is the classic Berkeley additive generator carried into glibc’s
random() and therefore Linux glibc rand(). It is much better than the
15-bit System V LCG, but it is still a weak historical userspace PRNG.
Implementations